<?PHP
/**
 * class to create gzip compressed version of files in a given folder
 *
 * Set you start directory, all considered extentsions (default: html, htm, js, css) und the recursive flag (default: true)
 *
 * Usage (Examles):
 * - $objGZip = new GZip();	compressed all html, htm, js, css files starting in the current directory recursively
 * - $objGZip = new GZip("D:\user\MyFolder"); compressed all html, htm, js, css files starting in the directory: D:\user\MyFolder recursively
 * - $objGZip = new GZip(".", "htm,css"); compressed all htm and css files starting in the current directory recursively
 * - $objGZip = new GZip(".", "htm,css", false); compressed all htm and css files only in the current directory
 *
 * @author	Harry Kmpf <kontakt@kaempf-nk.de>
 * @version	1.0 - 2013-12-08
 * @license http://www.opensource.org/licenses/mit-license.php The MIT License
 */
class GZip {
//************************************************** Variables ***********************************************************************
/**
 * starting directory
 * @var string
 */
	private $strPath;

/**
 * file types (extentions) to compress
 * @var array
 */
	private $arrTypes=array();

/**
 * recursive search true / false
 * @var boolean
 */
	private $bolRec;

//************************************************** Methods *************************************************************************
/**
 * Constructor set 
 * @param string $strPath starting directory (default: current directory)
 * @param array $arrTypes file types (extentions) to compress (default: 'html,htm,js,css')
 * @param boolean $bolRec recursive search / compress (default: true)
 */
	public function __construct($strPath='.', $strTypes = 'html,htm,js,css', $bolRec=true) {

        $this->strPath = $strPath;
		if ($strTypes) $this->arrTypes = explode(',',strtolower($strTypes));
        $this->bolRec = $bolRec;
		
		$this->getDirs($this->strPath);
	}

/**
 * list all directories and collect the result in a array
 * @param string $path directory
 * @return none
 */
   private function getDirs($path) {
		if (is_dir($path)) {
			if ($handle = opendir($path)) {
				while (false !== ($file = readdir($handle))) {
					if($file == '.' || $file == '..'){				// skip
					} else {
						if (is_dir($path."\\".$file)){
							if($this->bolRec === true){				// go to next level, if recursively
								$this->getDirs($path."\\".$file);
							}
						} else {
																	// check files against the valid extensions
							if (!in_array(strtolower(substr(strrchr($file,'.'),1)),$this->arrTypes)) continue;

							$this->compressFile($path.'\\'.$file);	// compress file
						}
					}
				}
			}
			closedir($handle);
        }
    }

/**
 * writes the contents of a given file to the gz-file
 * @param string $source complete filename ($path\$file)
 * @return none
 */
	private function compressFile($source) {

		echo $source.' => ';
  
		$hdl = fopen ($source, "r");
		$contents = fread($hdl, filesize($source));
		fclose($hdl);

		$dest=$source.'.gz';
		$zp = gzopen($dest, "w9");
		gzwrite($zp, $contents);
		gzclose($zp);

		echo $dest." ... done<br>\r\n";

    }
}
?>